#! /bin/sh
#
# Import script for prosper data export files.  This creates the necessary
# tables and populates them.
#
# Warning!  This script drops any existing tables with the same names
# and creates lots of temporary files.  It takes a long time to run and
# uses a lot of disk space.

# this is the name of your database schema, where tables should be created
DATABASE_SCHEMA=depot_development

# Perl program files; these should all come in the same package as this script
SCHEMA_PARSER=xsd2mysql.pl
DATA_INSERTER=xml2inserts.pl
PUBLIC_DATA_XSD=ProsperDataExport.xsd
PUBLIC_DATA_FILE=ProsperDataExport.xml
PRIVATE_DATA_XSD=ProsperDataPrivateExport.xsd
PRIVATE_DATA_FILE=ProsperDataPrivateExport.xml

# external programs; these are required for this script to work
PERL=perl
DATABASE_PROGRAM=mysql

for executable in $PERL $DATABASE_PROGRAM
do
	type $executable
	if [ $? != 0 ]
	then
		echo "$executable should be executable, bailing!"
		exit 1
	fi
done

for executable in $SCHEMA_PARSER $DATA_INSERTER
do
	if [ ! -e $executable ]
	then
		echo "$executable should be executable, bailing!"
		exit 1
	fi
done

for xsd_file in $PUBLIC_DATA_XSD $PRIVATE_DATA_XSD
do
	if [ ! -r $xsd_file ]
	then
		echo "$xsd_file should be readable, bailing!"
		exit 1
	fi
done

for data_file in $PUBLIC_DATA_FILE $PRIVATE_DATA_FILE
do
	if [ ! -r $data_file ]
	then
		echo "$data_file should be readable, bailing!"
		exit 1
	fi
done

echo "figuring out a safe temporary directory..."
i=0
TMP_DIR=t0
while [ -e $TMP_DIR ]
do
	i=`expr $i + 1`
	TMP_DIR=t${i}
done
mkdir $TMP_DIR
echo "using $TMP_DIR for temporary directory"

echo "creating schema for public data..."
$PERL $SCHEMA_PARSER $PUBLIC_DATA_XSD > create_public.sql
if [ $? -ne 0 ]; then exit $?; fi
$DATABASE_PROGRAM $DATABASE_SCHEMA < create_public.sql
if [ $? -ne 0 ]; then exit $?; fi
echo "creating SQL to import public data..."
$PERL $DATA_INSERTER $PUBLIC_DATA_FILE | split -a4 -l10000 - $TMP_DIR/pu
if [ $? -ne 0 ]; then exit $?; fi
echo "importing public data..."
for f in $TMP_DIR/pu????; do $DATABASE_PROGRAM $DATABASE_SCHEMA < $f; done
if [ $? -ne 0 ]; then exit $?; fi

echo "creating schema for private data..."
$PERL $SCHEMA_PARSER $PRIVATE_DATA_XSD > create_private.sql
if [ $? -ne 0 ]; then exit $?; fi
$DATABASE_PROGRAM $DATABASE_SCHEMA < create_private.sql
if [ $? -ne 0 ]; then exit $?; fi
echo "creating SQL to import private data..."
$PERL $DATA_INSERTER $PRIVATE_DATA_FILE | split -a4 -l10000 - $TMP_DIR/pr
if [ $? -ne 0 ]; then exit $?; fi
echo "importing public data..."
for f in $TMP_DIR/pr????; do $DATABASE_PROGRAM $DATABASE_SCHEMA < $f; done
if [ $? -ne 0 ]; then exit $?; fi

