#! /usr/bin/perl -w

=head1 NAME

xsd2mysql.pl - create SQL tables from Prosper data export XSD file

=head1 SYNOPSIS

  xsd2mysql.pl <input XSD file>

Where "input XSD file" is the name of a file containing the Prosper data
export schema.  There are typically two of these, one named
ProsperDataExport.xsd and one ProsperDataPrivateExport.xsd.

=head1 DESCRIPTION

This program reads the Prosper data export schema and writes SQL to create
appropriate tables to hold the dta exported from Prosper.  Output is
written to standard output -- this can be saved to a file or piped directly
into mysql if you are feeling lucky.

This is intended for MySQL but should be usable with other databases with
fairly minor changes.  (See comments in the code and in ProsperXsdParser.pm.)

=head1 SEE ALSO

xml2inserts.pl -- used to import data into the tables created by this script

=cut

use strict;

use ProsperXsdParser;

if (@ARGV != 1 or ! -f $ARGV[0]) {
        die "usage: $0 <input XML file>\n";
}

my $parser = new ProsperXsdParser($ARGV[0]);


my $tables = $parser->{TABLES};
for my $table_name (keys %{$tables}) {
	# the "IF EXISTS" syntax is MySQL -- edit/remove as appropriate
	print "DROP TABLE IF EXISTS $table_name;\n";
	print "CREATE TABLE $table_name (\n";

	# It's efficient to have an artificial integer key in MySQL
	# "id" is a convention from Ruby on Rails.
	print " id     int not null auto_increment,\n";

	# Most tables will have a "ProsperKey": this is useful for joining
	# tables and should be indexed if possible.
	my $prosper_key_seen = 0;

	my $table = $tables->{$table_name};
	for (my $i = 0; $i < @$table; $i++) {
		my $column = $table->[$i];
		my $column_name = $column->[0];
		$prosper_key_seen++ if ($column_name eq 'ProsperKey');
		my $column_type = $column->[1];
		print " $column_name\t$column_type";
		print ",\n";
	}
	print " PRIMARY KEY (id)";
	if ($prosper_key_seen) {
		print ",\n UNIQUE KEY(ProsperKey)\n";
	}
	print ");\n";
}

